package de.juplo.jpa.converters;

import java.time.Duration;
import java.time.temporal.ChronoUnit;
import java.time.temporal.TemporalAmount;
import javax.persistence.AttributeConverter;
import javax.persistence.Converter;


/**
 * Converts a {@link TemporalAmount} into a {@link Long} representing days.
 * @author Kai Moritz
 */
@Converter
public class TemporalAmountToDaysConverter implements AttributeConverter<TemporalAmount, Long>
{
  @Override
  public Long convertToDatabaseColumn(TemporalAmount amount)
  {
    return amount.get(ChronoUnit.DAYS);
  }

  @Override
  public TemporalAmount convertToEntityAttribute(Long days)
  {
    return Duration.ofDays(days);
  }
}
