package de.juplo.jpa.converters;

import java.time.Duration;
import java.time.temporal.ChronoUnit;
import java.time.temporal.TemporalAmount;
import javax.persistence.AttributeConverter;
import javax.persistence.Converter;


/**
 * Converts a {@link TemporalAmount} into a {@link Long} representing seconds.
 * @author Kai Moritz
 */
@Converter
public class TemporalAmountToSecondsConverter implements AttributeConverter<TemporalAmount, Long>
{
  @Override
  public Long convertToDatabaseColumn(TemporalAmount amount)
  {
    return amount.get(ChronoUnit.SECONDS);
  }

  @Override
  public TemporalAmount convertToEntityAttribute(Long seconds)
  {
    return Duration.ofSeconds(seconds);
  }
}
